#[non_exhaustive]pub struct BatchCreateFirewallRuleOutput {
pub created_firewall_rules: Option<Vec<FirewallRule>>,
pub create_errors: Option<Vec<BatchCreateFirewallRuleError>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.created_firewall_rules: Option<Vec<FirewallRule>>The firewall rules that were successfully created by the request.
create_errors: Option<Vec<BatchCreateFirewallRuleError>>A list of errors that occurred while creating the firewall rules.
Implementations
Sourceimpl BatchCreateFirewallRuleOutput
impl BatchCreateFirewallRuleOutput
Sourcepub fn created_firewall_rules(&self) -> &[FirewallRule]
pub fn created_firewall_rules(&self) -> &[FirewallRule]
The firewall rules that were successfully created by the request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .created_firewall_rules.is_none().
Sourcepub fn create_errors(&self) -> &[BatchCreateFirewallRuleError]
pub fn create_errors(&self) -> &[BatchCreateFirewallRuleError]
A list of errors that occurred while creating the firewall rules.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .create_errors.is_none().
Sourceimpl BatchCreateFirewallRuleOutput
impl BatchCreateFirewallRuleOutput
Sourcepub fn builder() -> BatchCreateFirewallRuleOutputBuilder
pub fn builder() -> BatchCreateFirewallRuleOutputBuilder
Creates a new builder-style object to manufacture BatchCreateFirewallRuleOutput.