#[non_exhaustive]pub struct CreateFirewallRuleEntry {Show 15 fields
pub creator_request_id: String,
pub firewall_rule_group_id: String,
pub firewall_domain_list_id: Option<String>,
pub priority: i32,
pub action: Action,
pub block_response: Option<BlockResponse>,
pub block_override_domain: Option<String>,
pub block_override_dns_type: Option<BlockOverrideDnsType>,
pub block_override_ttl: Option<i32>,
pub name: String,
pub firewall_domain_redirection_action: Option<FirewallDomainRedirectionAction>,
pub qtype: Option<String>,
pub dns_threat_protection: Option<DnsThreatProtection>,
pub confidence_threshold: Option<ConfidenceThreshold>,
pub firewall_rule_type: Option<FirewallRuleType>,
}Expand description
The details for creating a single firewall rule in a batch operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creator_request_id: StringA unique string that identifies the request and that allows you to retry failed requests without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp.
firewall_rule_group_id: StringThe unique identifier of the firewall rule group where you want to create the rule.
firewall_domain_list_id: Option<String>The ID of the domain list that you want to use in the rule. This setting is mutually exclusive with DnsThreatProtection and FirewallRuleType.
priority: i32The setting that determines the processing order of the rule in the rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting.
action: ActionThe action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list, or a threat in a DNS Firewall Advanced rule:
-
ALLOW- Permit the request to go through. Not available for DNS Firewall Advanced rules. -
ALERT- Permit the request and send metrics and logs to CloudWatch. -
BLOCK- Disallow the request. This option requires additional details in the rule'sBlockResponse.
block_response: Option<BlockResponse>The way that you want DNS Firewall to block the request, used with the rule action setting BLOCK.
-
NODATA- Respond indicating that the query was successful, but no response is available for it. -
NXDOMAIN- Respond indicating that the domain name that's in the query doesn't exist. -
OVERRIDE- Provide a custom override in the response. This option requires custom handling details in the rule'sBlockOverride*settings.
block_override_domain: Option<String>The custom DNS record to send back in response to the query. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE.
block_override_dns_type: Option<BlockOverrideDnsType>The DNS record's type. This determines the format of the record value that you provided in BlockOverrideDomain. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE.
block_override_ttl: Option<i32>The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE.
This setting is required if the BlockResponse setting is OVERRIDE.
name: StringA name that lets you identify the rule in the rule group.
firewall_domain_redirection_action: Option<FirewallDomainRedirectionAction>How you want the rule to evaluate DNS redirection in the DNS redirection chain, such as CNAME or DNAME.
INSPECT_REDIRECTION_DOMAIN: (Default) inspects all domains in the redirection chain. The individual domains in the redirection chain must be added to the domain list.
TRUST_REDIRECTION_DOMAIN: Inspects only the first domain in the redirection chain. You don't need to add the subsequent domains in the redirection list to the domain list.
qtype: Option<String>The DNS query type you want the rule to evaluate. Allowed values are:
-
A: Returns an IPv4 address.
-
AAAA: Returns an IPv6 address.
-
CAA: Restricts CAs that can create SSL/TLS certifications for the domain.
-
CNAME: Returns another domain name.
-
DS: Record that identifies the DNSSEC signing key of a delegated zone.
-
MX: Specifies mail servers.
-
NAPTR: Regular-expression-based rewriting of domain names.
-
NS: Authoritative name servers.
-
PTR: Maps an IP address to a domain name.
-
SOA: Start of authority record for the zone.
-
SPF: Lists the servers authorized to send emails from a domain.
-
SRV: Application specific values that identify servers.
-
TXT: Verifies email senders and application-specific values.
-
A query type you define by using the DNS type ID, for example 28 for AAAA. The values must be defined as TYPENUMBER, where the NUMBER can be 1-65534, for example, TYPE28. For more information, see List of DNS record types.
dns_threat_protection: Option<DnsThreatProtection>The type of the DNS Firewall Advanced rule. This setting is mutually exclusive with FirewallDomainListId and FirewallRuleType. Valid values are:
-
DGA: Domain generation algorithms detection. DGAs are used by attackers to generate a large number of domains to launch malware attacks. -
DNS_TUNNELING: DNS tunneling detection. DNS tunneling is used by attackers to exfiltrate data from the client by using the DNS tunnel without making a network connection to the client. -
DICTIONARY_DGA: Dictionary-based domain generation algorithms detection. Dictionary DGAs use wordlists to generate domains that appear more legitimate, making them harder to detect than traditional DGAs.
confidence_threshold: Option<ConfidenceThreshold>The confidence threshold for DNS Firewall Advanced. You must provide this value when you create or update a DNS Firewall Advanced rule. The confidence level values mean:
-
LOW: Provides the highest detection rate for threats, but also increases false positives. -
MEDIUM: Provides a balance between detecting threats and false positives. -
HIGH: Detects only the most well corroborated threats with a low rate of false positives.
firewall_rule_type: Option<FirewallRuleType>The rule type configuration for the firewall rule. This is a tagged union — set exactly one of its members. This setting is mutually exclusive with the top-level FirewallDomainListId and DnsThreatProtection fields. Use one of:
-
FirewallAdvancedContentCategory— match an AWS-managed content category (for example,VIOLENCE_AND_HATE_SPEECH). -
FirewallAdvancedThreatCategory— match an AWS-managed advanced threat category (for example,PHISHING). -
DnsThreatProtection— match a built-in DNS Firewall Advanced threat detector (DGA,DNS_TUNNELING, orDICTIONARY_DGA). -
PartnerThreatProtection— match a third-party threat feed delivered through AWS Marketplace. The selected partner must be an active subscription on the calling account.
To enumerate the values supported in your account, call ListFirewallRuleTypes.
Implementations
Sourceimpl CreateFirewallRuleEntry
impl CreateFirewallRuleEntry
Sourcepub fn creator_request_id(&self) -> &str
pub fn creator_request_id(&self) -> &str
A unique string that identifies the request and that allows you to retry failed requests without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp.
Sourcepub fn firewall_rule_group_id(&self) -> &str
pub fn firewall_rule_group_id(&self) -> &str
The unique identifier of the firewall rule group where you want to create the rule.
Sourcepub fn firewall_domain_list_id(&self) -> Option<&str>
pub fn firewall_domain_list_id(&self) -> Option<&str>
The ID of the domain list that you want to use in the rule. This setting is mutually exclusive with DnsThreatProtection and FirewallRuleType.
Sourcepub fn priority(&self) -> i32
pub fn priority(&self) -> i32
The setting that determines the processing order of the rule in the rule group. DNS Firewall processes the rules in a rule group by order of priority, starting from the lowest setting.
Sourcepub fn action(&self) -> &Action
pub fn action(&self) -> &Action
The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list, or a threat in a DNS Firewall Advanced rule:
-
ALLOW- Permit the request to go through. Not available for DNS Firewall Advanced rules. -
ALERT- Permit the request and send metrics and logs to CloudWatch. -
BLOCK- Disallow the request. This option requires additional details in the rule'sBlockResponse.
Sourcepub fn block_response(&self) -> Option<&BlockResponse>
pub fn block_response(&self) -> Option<&BlockResponse>
The way that you want DNS Firewall to block the request, used with the rule action setting BLOCK.
-
NODATA- Respond indicating that the query was successful, but no response is available for it. -
NXDOMAIN- Respond indicating that the domain name that's in the query doesn't exist. -
OVERRIDE- Provide a custom override in the response. This option requires custom handling details in the rule'sBlockOverride*settings.
Sourcepub fn block_override_domain(&self) -> Option<&str>
pub fn block_override_domain(&self) -> Option<&str>
The custom DNS record to send back in response to the query. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE.
Sourcepub fn block_override_dns_type(&self) -> Option<&BlockOverrideDnsType>
pub fn block_override_dns_type(&self) -> Option<&BlockOverrideDnsType>
The DNS record's type. This determines the format of the record value that you provided in BlockOverrideDomain. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE.
Sourcepub fn block_override_ttl(&self) -> Option<i32>
pub fn block_override_ttl(&self) -> Option<i32>
The recommended amount of time, in seconds, for the DNS resolver or web browser to cache the provided override record. Used for the rule action BLOCK with a BlockResponse setting of OVERRIDE.
This setting is required if the BlockResponse setting is OVERRIDE.
Sourcepub fn firewall_domain_redirection_action(
&self,
) -> Option<&FirewallDomainRedirectionAction>
pub fn firewall_domain_redirection_action( &self, ) -> Option<&FirewallDomainRedirectionAction>
How you want the rule to evaluate DNS redirection in the DNS redirection chain, such as CNAME or DNAME.
INSPECT_REDIRECTION_DOMAIN: (Default) inspects all domains in the redirection chain. The individual domains in the redirection chain must be added to the domain list.
TRUST_REDIRECTION_DOMAIN: Inspects only the first domain in the redirection chain. You don't need to add the subsequent domains in the redirection list to the domain list.
Sourcepub fn qtype(&self) -> Option<&str>
pub fn qtype(&self) -> Option<&str>
The DNS query type you want the rule to evaluate. Allowed values are:
-
A: Returns an IPv4 address.
-
AAAA: Returns an IPv6 address.
-
CAA: Restricts CAs that can create SSL/TLS certifications for the domain.
-
CNAME: Returns another domain name.
-
DS: Record that identifies the DNSSEC signing key of a delegated zone.
-
MX: Specifies mail servers.
-
NAPTR: Regular-expression-based rewriting of domain names.
-
NS: Authoritative name servers.
-
PTR: Maps an IP address to a domain name.
-
SOA: Start of authority record for the zone.
-
SPF: Lists the servers authorized to send emails from a domain.
-
SRV: Application specific values that identify servers.
-
TXT: Verifies email senders and application-specific values.
-
A query type you define by using the DNS type ID, for example 28 for AAAA. The values must be defined as TYPENUMBER, where the NUMBER can be 1-65534, for example, TYPE28. For more information, see List of DNS record types.
Sourcepub fn dns_threat_protection(&self) -> Option<&DnsThreatProtection>
pub fn dns_threat_protection(&self) -> Option<&DnsThreatProtection>
The type of the DNS Firewall Advanced rule. This setting is mutually exclusive with FirewallDomainListId and FirewallRuleType. Valid values are:
-
DGA: Domain generation algorithms detection. DGAs are used by attackers to generate a large number of domains to launch malware attacks. -
DNS_TUNNELING: DNS tunneling detection. DNS tunneling is used by attackers to exfiltrate data from the client by using the DNS tunnel without making a network connection to the client. -
DICTIONARY_DGA: Dictionary-based domain generation algorithms detection. Dictionary DGAs use wordlists to generate domains that appear more legitimate, making them harder to detect than traditional DGAs.
Sourcepub fn confidence_threshold(&self) -> Option<&ConfidenceThreshold>
pub fn confidence_threshold(&self) -> Option<&ConfidenceThreshold>
The confidence threshold for DNS Firewall Advanced. You must provide this value when you create or update a DNS Firewall Advanced rule. The confidence level values mean:
-
LOW: Provides the highest detection rate for threats, but also increases false positives. -
MEDIUM: Provides a balance between detecting threats and false positives. -
HIGH: Detects only the most well corroborated threats with a low rate of false positives.
Sourcepub fn firewall_rule_type(&self) -> Option<&FirewallRuleType>
pub fn firewall_rule_type(&self) -> Option<&FirewallRuleType>
The rule type configuration for the firewall rule. This is a tagged union — set exactly one of its members. This setting is mutually exclusive with the top-level FirewallDomainListId and DnsThreatProtection fields. Use one of:
-
FirewallAdvancedContentCategory— match an AWS-managed content category (for example,VIOLENCE_AND_HATE_SPEECH). -
FirewallAdvancedThreatCategory— match an AWS-managed advanced threat category (for example,PHISHING). -
DnsThreatProtection— match a built-in DNS Firewall Advanced threat detector (DGA,DNS_TUNNELING, orDICTIONARY_DGA). -
PartnerThreatProtection— match a third-party threat feed delivered through AWS Marketplace. The selected partner must be an active subscription on the calling account.
To enumerate the values supported in your account, call ListFirewallRuleTypes.
Sourceimpl CreateFirewallRuleEntry
impl CreateFirewallRuleEntry
Sourcepub fn builder() -> CreateFirewallRuleEntryBuilder
pub fn builder() -> CreateFirewallRuleEntryBuilder
Creates a new builder-style object to manufacture CreateFirewallRuleEntry.